@@ -309,7 +309,7 @@ detect_cursor_inversion_wrapper(ncdirect* n, int* y, int* x){
 
 // no terminfo capability for this. dangerous--it involves writing controls to
 // the terminal, and then reading a response. many things can distupt this
-// non-atomic procedure.
+// non-atomic procedure, leading to unexpected results. a garbage function.
 int ncdirect_cursor_yx(ncdirect* n, int* y, int* x){
   struct termios termio, oldtermios;
   // this is only meaningful for real terminals
@@ -321,7 +321,7 @@ int ncdirect_cursor_yx(ncdirect* n, int* y, int* x){
     return -1;
   }
   memcpy(&oldtermios, &termio, sizeof(termio));
-  // we should already be in cbreak mode from ncdirect_init(), but just in case
+  // we might already be in cbreak mode from ncdirect_init(), but just in case
   // it got changed by the client code since then, duck into cbreak mode anew.
   termio.c_lflag &= ~(ICANON | ECHO);
   if(tcsetattr(n->ctermfd, TCSAFLUSH, &termio)){
@@ -597,7 +597,7 @@ static int
 ncdirect_stop_minimal(void* vnc){
   ncdirect* nc = static_cast<ncdirect*>(vnc);
   int ret = drop_signals(nc);
-  if(!(nc->flags & NCDIRECT_OPTION_NO_READLINE)){
+  if(nc->initialized_readline){
     rl_deprep_terminal();
   }
   if(nc->tcache.op && term_emit("op", nc->tcache.op, nc->ttyfp, true)){
@@ -613,9 +613,7 @@ ncdirect_stop_minimal(void* vnc){
     if(nc->tcache.cnorm && tty_emit("cnorm", nc->tcache.cnorm, nc->ctermfd)){
       ret = -1;
     }
-    if(!(nc->flags & NCDIRECT_OPTION_INHIBIT_CBREAK)){
-      ret |= tcsetattr(nc->ctermfd, TCSANOW, &nc->tpreserved);
-    }
+    ret |= tcsetattr(nc->ctermfd, TCSANOW, &nc->tpreserved);
     ret |= close(nc->ctermfd);
   }
   return ret;
@@ -649,11 +647,11 @@ ncdirect* ncdirect_core_init(const char* termtype, FILE* outfp, uint64_t flags){
   }
   // we don't need a controlling tty for everything we do; allow a failure here
   if((ret->ctermfd = get_controlling_tty(ret->ttyfp)) >= 0){
+    if(tcgetattr(ret->ctermfd, &ret->tpreserved)){
+      fprintf(stderr, "Couldn't preserve terminal state for %d (%s)\n", ret->ctermfd, strerror(errno));
+      goto err;
+    }
     if(!(flags & NCDIRECT_OPTION_INHIBIT_CBREAK)){
-      if(tcgetattr(ret->ctermfd, &ret->tpreserved)){
-        fprintf(stderr, "Couldn't preserve terminal state for %d (%s)\n", ret->ctermfd, strerror(errno));
-        goto err;
-      }
       if(cbreak_mode(ret->ctermfd, &ret->tpreserved)){
         goto err;
       }
@@ -675,20 +673,12 @@ ncdirect* ncdirect_core_init(const char* termtype, FILE* outfp, uint64_t flags){
   if(interrogate_terminfo(&ret->tcache, shortname_term)){
     goto err;
   }
-  ret->channels = 0;
   ncdirect_set_styles(ret, 0);
-  if(!(flags & NCDIRECT_OPTION_NO_READLINE)){
-    rl_outstream = outfp;
-    rl_instream = stdin;
-    rl_prep_terminal(1); // 1 == read 8-bit input
-  }
   return ret;
 
 err:
   if(ret->ctermfd >= 0){
-    if(!(flags & NCDIRECT_OPTION_INHIBIT_CBREAK)){
-      tcsetattr(ret->ctermfd, TCSANOW, &ret->tpreserved);
-    }
+    tcsetattr(ret->ctermfd, TCSANOW, &ret->tpreserved);
   }
   drop_signals(ret);
   delete(ret);
@@ -705,6 +695,16 @@ int ncdirect_stop(ncdirect* nc){
   return ret;
 }
 
+char* ncdirect_readline(ncdirect* n, const char* prompt){
+  if(!n->initialized_readline){
+    rl_outstream = n->ttyfp;
+    rl_instream = stdin;
+    rl_prep_terminal(1); // 1 == read 8-bit input
+    n->initialized_readline = true;
+  }
+  return readline(prompt);
+}
+
 static inline int
 ncdirect_style_emit(ncdirect* n, unsigned stylebits, FILE* out){
   int r = -1;
@@ -1070,8 +1070,7 @@ bool ncdirect_canutf8(const ncdirect* n){
 }
 
 int ncdirect_flush(const ncdirect* nc){
-  int r;
-  while((r = fflush(nc->ttyfp)) == EOF){
+  while(fflush(nc->ttyfp) == EOF){
     if(errno != EAGAIN){
       return -1;
     }
