@@ -31,6 +31,14 @@ extern "C" {
 struct esctrie;
 struct ncvisual_details;
 
+// Does this glyph completely obscure the background? If so, there's no need
+// to emit a background when rasterizing, a small optimization.
+#define CELL_NOBACKGROUND_MASK  0x8700000000000000ull
+
+// Was this glyph drawn as part of an ncvisual? If so, we need to honor
+// blitter stacking rather than the standard trichannel solver.
+#define CELL_BLITTERSTACK_MASK  0x8700000000000000ull
+
 // we can't define multipart ncvisual here, because OIIO requires C++ syntax,
 // and we can't go throwing C++ syntax into this header. so it goes.
 
@@ -302,6 +310,7 @@ typedef struct ncdirect {
   // typical order. we detect it the first time ncdirect_cursor_yx() is called.
   bool detected_cursor_inversion; // have we performed inversion testing?
   bool inverted_cursor;      // does the terminal return inverted coordinates?
+  bool initialized_readline; // have we initialized Readline?
   uint64_t flags;            // copied in ncdirect_init() from param
 } ncdirect;
 
@@ -309,10 +318,11 @@ typedef struct ncpile {
   ncplane* top;               // topmost plane, never NULL
   ncplane* bottom;            // bottommost plane, never NULL
   ncplane* roots;             // head of root plane list
+  struct crender* crender;    // array (rows * cols crender objects)
   struct notcurses* nc;       // notcurses context
   struct ncpile *prev, *next; // circular list
+  size_t crenderlen;          // size of crender vector
   int dimy, dimx;             // rows and cols at time of render
-  struct crender* crender;    // array (rows * cols crender objects)
 } ncpile;
 
 // the standard pile can be reached through ->stdplane.
@@ -367,31 +377,6 @@ void warn_terminfo(const notcurses* nc, const tinfo* ti);
 
 int resize_callbacks_children(ncplane* n);
 
-// Search the provided multibyte (UTF8) string 's' for the provided unicode
-// codepoint 'cp'. If found, return the column offset of the EGC in which the
-// codepoint appears in 'col', and the byte offset as the return value. If not
-// found, -1 is returned, and 'col' is meaningless.
-static inline int
-mbstr_find_codepoint(const char* s, char32_t cp, int* col){
-  mbstate_t ps;
-  memset(&ps, 0, sizeof(ps));
-  size_t bytes = 0;
-  size_t r;
-  wchar_t w;
-  *col = 0;
-  while((r = mbrtowc(&w, s + bytes, MB_CUR_MAX, &ps)) != (size_t)-1 && r != (size_t)-2){
-    if(r == 0){
-      break;
-    }
-    if(towlower(cp) == towlower(w)){
-      return bytes;
-    }
-    *col += wcwidth(w);
-    bytes += r;
-  }
-  return -1;
-}
-
 static inline ncpile*
 ncplane_pile(ncplane* n){
   return n->pile;
@@ -865,7 +850,31 @@ box_corner_needs(unsigned ctlword){
 // solid or shaded block, or certain emoji).
 static inline bool
 cell_nobackground_p(const nccell* c){
-  return c->channels & CELL_NOBACKGROUND_MASK;
+  return (c->channels & CELL_NOBACKGROUND_MASK) == CELL_NOBACKGROUND_MASK;
+}
+
+// Returns a number 0 <= n <= 15 representing the four quadrants, and which (if
+// any) are occupied due to blitting with a transparent background. The mapping
+// is {tl, tr, bl, br}.
+static inline unsigned
+cell_blittedquadrants(const nccell* c){
+  return ((c->channels & 0x8000000000000000ull) ? 1 : 0) |
+         ((c->channels & 0x0400000000000000ull) ? 2 : 0) |
+         ((c->channels & 0x0200000000000000ull) ? 4 : 0) |
+         ((c->channels & 0x0100000000000000ull) ? 8 : 0);
+}
+
+// Set this whenever blitting an ncvisual, when we have a transparent
+// background. In such cases, ncvisuals underneath the cell must be rendered
+// slightly differently.
+static inline void
+cell_set_blitquadrants(nccell* c, unsigned tl, unsigned tr, unsigned bl, unsigned br){
+  // FIXME want a static assert that these four constants OR together to
+  // equal CELL_BLITTERSTACK_MASK, bah
+  c->channels |= (tl ? 0x8000000000000000ull : 0);
+  c->channels |= (tr ? 0x0400000000000000ull : 0);
+  c->channels |= (bl ? 0x0200000000000000ull : 0);
+  c->channels |= (br ? 0x0100000000000000ull : 0);
 }
 
 // Destroy a plane and all its bound descendants.
@@ -944,9 +953,8 @@ egc_rtl(const char* egc, int* bytes){
 }
 
 // lowest level of cell+pool setup. if the EGC changes the output to RTL, it
-// must be suffixed with a LTR-forcing character by now, and both
-// CELL_WIDEASIAN_MASK and CELL_NOBACKGROUND_MASK ought be set however they're
-// going to be set.
+// must be suffixed with a LTR-forcing character by now, and
+// CELL_NOBACKGROUND_MASK ought be set however it's going to be set.
 static inline int
 pool_blit_direct(egcpool* pool, nccell* c, const char* gcluster, int bytes, int cols){
   pool_release(pool, c);
@@ -1060,21 +1068,25 @@ int drop_signals(void* nc);
 void ncvisual_printbanner(const notcurses* nc);
 
 typedef struct ncvisual_implementation {
-  int (*ncvisual_init)(int loglevel);
-  void (*ncvisual_printbanner)(const struct notcurses* nc);
-  int (*ncvisual_blit)(struct ncvisual* ncv, int rows, int cols, ncplane* n,
-                       const struct blitset* bset, int placey, int placex,
-                       int begy, int begx, int leny, int lenx,
-                       bool blendcolors);
-  struct ncvisual* (*ncvisual_create)(void);
-  struct ncvisual* (*ncvisual_from_file)(const char* fname);
+  int (*visual_init)(int loglevel);
+  void (*visual_printbanner)(const struct notcurses* nc);
+  int (*visual_blit)(struct ncvisual* ncv, int rows, int cols, ncplane* n,
+                     const struct blitset* bset, int placey, int placex,
+                     int begy, int begx, int leny, int lenx,
+                     bool blendcolors);
+  struct ncvisual* (*visual_create)(void);
+  struct ncvisual* (*visual_from_file)(const char* fname);
   // ncv constructors other than ncvisual_from_file() need to set up the
   // AVFrame* 'frame' according to their own data, which is assumed to
   // have been prepared already in 'ncv'.
-  void (*ncvisual_details_seed)(struct ncvisual* ncv);
-  void (*ncvisual_details_destroy)(struct ncvisual_details* deets);
-  int (*ncvisual_decode)(struct ncvisual* nc);
-  char* (*ncvisual_subtitle)(const struct ncvisual* ncv);
+  void (*visual_details_seed)(struct ncvisual* ncv);
+  void (*visual_details_destroy)(struct ncvisual_details* deets);
+  int (*visual_decode)(struct ncvisual* nc);
+  int (*visual_decode_loop)(struct ncvisual* nc);
+  int (*visual_stream)(notcurses* nc, struct ncvisual* ncv, float timescale,
+                       streamcb streamer, const struct ncvisual_options* vopts, void* curry);
+  char* (*visual_subtitle)(const struct ncvisual* ncv);
+  int (*visual_resize)(struct ncvisual* ncv, int rows, int cols);
   bool canopen_images;
   bool canopen_videos;
 } ncvisual_implementation;
