@@ -262,6 +262,7 @@ make_ncpile(notcurses* nc, ncplane* n){
     ret->dimy = 0;
     ret->dimx = 0;
     ret->crender = NULL;
+    ret->crenderlen = 0;
   }
   return ret;
 }
@@ -631,6 +632,27 @@ int ncplane_destroy(ncplane* ncp){
     return -1;
   }
 //notcurses_debug(ncplane_notcurses(ncp), stderr);
+  int ret = 0;
+  // dissolve our binding from behind (->bprev is either NULL, or its
+  // predecessor on the bound list's ->bnext, or &ncp->boundto->blist)
+  if(ncp->bprev){
+    if( (*ncp->bprev = ncp->bnext) ){
+      ncp->bnext->bprev = ncp->bprev;
+    }
+  }
+  // recursively reparent our children to the plane to which we are bound.
+  // this will extract each one from the sibling list.
+  struct ncplane* bound = ncp->blist;
+  while(bound){
+    struct ncplane* tmp = bound->bnext;
+    if(ncplane_reparent_family(bound, ncp->boundto) == NULL){
+      ret = -1;
+    }
+    bound = tmp;
+  }
+  // extract ourselves from the z-axis. do this *after* reparenting, in case
+  // reparenting shifts up the z-axis somehow (though i don't think it can,
+  // at least not within a pile?).
   if(ncp->above){
     ncp->above->below = ncp->below;
   }else{
@@ -641,20 +663,7 @@ int ncplane_destroy(ncplane* ncp){
   }else{
     ncplane_pile(ncp)->bottom = ncp->above;
   }
-  if(ncp->bprev){
-    if( (*ncp->bprev = ncp->bnext) ){
-      ncp->bnext->bprev = ncp->bprev;
-    }
-  }
-  int ret = 0;
-  struct ncplane* bound = ncp->blist;
-  while(bound){
-    struct ncplane* tmp = bound->bnext;
-    if(ncplane_reparent_family(bound, ncp->boundto) == NULL){
-      ret = -1;
-    }
-    bound = tmp;
-  }
+  // no need to NULL out our ->boundto, as we are about to die (and unlinked)
   free_plane(ncp);
   return ret;
 }
@@ -694,6 +703,7 @@ reset_stats(ncstats* stats){
   memset(stats, 0, sizeof(*stats));
   stats->render_min_ns = 1ull << 62u;
   stats->render_min_bytes = 1ull << 62u;
+  stats->raster_min_ns = 1ull << 62u;
   stats->writeout_min_ns = 1ull << 62u;
   stats->fbbytes = fbbytes;
 }
@@ -703,6 +713,7 @@ static void
 stash_stats(notcurses* nc){
   nc->stashstats.renders += nc->stats.renders;
   nc->stashstats.render_ns += nc->stats.render_ns;
+  nc->stashstats.raster_ns += nc->stats.raster_ns;
   nc->stashstats.writeouts += nc->stats.writeouts;
   nc->stashstats.writeout_ns += nc->stats.writeout_ns;
   nc->stashstats.failed_renders += nc->stats.failed_renders;
@@ -726,6 +737,12 @@ stash_stats(notcurses* nc){
   if(nc->stashstats.writeout_min_ns > nc->stats.writeout_min_ns){
     nc->stashstats.writeout_min_ns = nc->stats.writeout_min_ns;
   }
+  if(nc->stashstats.raster_max_ns < nc->stats.raster_max_ns){
+    nc->stashstats.raster_max_ns = nc->stats.raster_max_ns;
+  }
+  if(nc->stashstats.raster_min_ns > nc->stats.raster_min_ns){
+    nc->stashstats.raster_min_ns = nc->stats.raster_min_ns;
+  }
   nc->stashstats.cellelisions += nc->stats.cellelisions;
   nc->stashstats.cellemissions += nc->stats.cellemissions;
   nc->stashstats.fgelisions += nc->stats.fgelisions;
@@ -1145,6 +1162,13 @@ int notcurses_stop(notcurses* nc){
         fprintf(stderr, "\n%ju render%s, %ss total (%ss min, %ss max, %ss avg)\n",
                 nc->stashstats.renders, nc->stashstats.renders == 1 ? "" : "s",
                 totalbuf, minbuf, maxbuf, avgbuf);
+        qprefix(nc->stashstats.raster_ns, NANOSECS_IN_SEC, totalbuf, 0);
+        qprefix(nc->stashstats.raster_min_ns, NANOSECS_IN_SEC, minbuf, 0);
+        qprefix(nc->stashstats.raster_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
+        qprefix(nc->stashstats.raster_ns / nc->stashstats.writeouts, NANOSECS_IN_SEC, avgbuf, 0);
+        fprintf(stderr, "%ju raster%s, %ss total (%ss min, %ss max, %ss avg)\n",
+                nc->stashstats.writeouts, nc->stashstats.writeouts == 1 ? "" : "s",
+                totalbuf, minbuf, maxbuf, avgbuf);
         qprefix(nc->stashstats.writeout_ns, NANOSECS_IN_SEC, totalbuf, 0);
         qprefix(nc->stashstats.writeout_min_ns, NANOSECS_IN_SEC, minbuf, 0);
         qprefix(nc->stashstats.writeout_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
