@@ -152,6 +152,23 @@ update_render_stats(const struct timespec* time1, const struct timespec* time0,
   }
 }
 
+static void
+update_raster_stats(const struct timespec* time1, const struct timespec* time0,
+                    ncstats* stats){
+  const int64_t elapsed = timespec_to_ns(time1) - timespec_to_ns(time0);
+  //fprintf(stderr, "Rasterizing took %ld.%03lds\n", elapsed / NANOSECS_IN_SEC,
+  //        (elapsed % NANOSECS_IN_SEC) / 1000000);
+  if(elapsed > 0){ // don't count clearly incorrect information, egads
+    stats->raster_ns += elapsed;
+    if(elapsed > stats->raster_max_ns){
+      stats->raster_max_ns = elapsed;
+    }
+    if(elapsed < stats->raster_min_ns){
+      stats->raster_min_ns = elapsed;
+    }
+  }
+}
+
 void cell_release(ncplane* n, nccell* c){
   pool_release(&n->pool, c);
 }
@@ -170,17 +187,31 @@ int cell_duplicate(ncplane* n, nccell* targ, const nccell* c){
 struct crender {
   const ncplane *p; // source of glyph for this cell
   nccell c;
-  unsigned fgblends;
-  unsigned bgblends;
-  // we'll need recalculate the foreground relative to the solved background,
-  // and then reapply any foreground shading from above the highcontrast
-  // declaration. save the foreground state when we go highcontrast.
-  unsigned hcfgblends; // number of foreground blends prior to HIGHCONTRAST
-  uint32_t hcfg;       // foreground channel prior to HIGHCONTRAST
-  bool damaged;        // also used in rasterization
-  // if CELL_ALPHA_HIGHCONTRAST is in play, we apply the HSV flip once the
-  // background is locked in. set highcontrast to indicate this.
-  bool highcontrast;
+  uint32_t hcfg;       // fg channel prior to HIGHCONTRAST (need full channel)
+  struct {
+    // If the glyph we render is from an ncvisual, and has a transparent or
+    // blended background, blitter stacking is in effect. This is a complicated
+    // issue, but essentially, imagine a bottom block is rendered with a green
+    // bottom and transparent top. on a lower plane, a top block is rendered
+    // with a red foreground and blue background. Normally, this would result
+    // in a blue top and green bottom, but that's not what we ever wanted --
+    // what makes sense is a red top and green bottom. So ncvisual rendering
+    // sets bits from CELL_BLITTERSTACK_MASK when rendering a cell with a
+    // transparent background. When paint() selects a glyph, it checks for these
+    // bits. If they are set, any lower planes with CELL_BLITTERSTACK_MASK set
+    // take this into account when solving the background color.
+    unsigned blittedquads: 4;
+    unsigned damaged: 1; // only used in rasterization
+    // if CELL_ALPHA_HIGHCONTRAST is in play, we apply the HSV flip once the
+    // background is locked in. set highcontrast to indicate this.
+    unsigned highcontrast: 1;
+    unsigned fgblends: 8;
+    unsigned bgblends: 8;
+    // we'll need recalculate the foreground relative to the solved background,
+    // and then reapply any foreground shading from above the highcontrast
+    // declaration. save the foreground state when we go highcontrast.
+    unsigned hcfgblends: 8; // number of foreground blends prior to HIGHCONTRAST
+  } s;
 };
 
 // Emit fchannel with RGB changed to contrast effectively against bchannel.
@@ -253,7 +284,7 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
     if(absy >= dstleny || absy < 0){
       break;
     }
-    for(x = startx ; x < dimx ; ++x){
+    for(x = startx ; x < dimx ; ++x){ // iteration for each cell
       const int absx = x + offx;
       if(absx >= dstlenx || absx < 0){
         break;
@@ -263,24 +294,6 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
       if(cell_wide_right_p(targc)){
         continue;
       }
-      // Background color takes effect independently of whether we have a
-      // glyph. If we've already locked in the background, it has no effect.
-      // If it's transparent, it has no effect. Otherwise, update the
-      // background channel and balpha.
-      // Evaluate the background first, in case we have HIGHCONTRAST fg text.
-      if(cell_bg_alpha(targc) > CELL_ALPHA_OPAQUE){
-        const nccell* vis = &p->fb[nfbcellidx(p, y, x)];
-        if(cell_bg_default_p(vis)){
-          vis = &p->basecell;
-        }
-        if(cell_bg_palindex_p(vis)){
-          if(cell_bg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
-            cell_set_bg_palindex(targc, cell_bg_palindex(vis));
-          }
-        }else{
-          cell_blend_bchannel(targc, cell_bchannel(vis), &crender->bgblends);
-        }
-      }
 
       if(cell_fg_alpha(targc) > CELL_ALPHA_OPAQUE){
         const nccell* vis = &p->fb[nfbcellidx(p, y, x)];
@@ -293,20 +306,63 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
           }
         }else{
           if(cell_fg_alpha(vis) == CELL_ALPHA_HIGHCONTRAST){
-            crender->highcontrast = true;
-            crender->hcfgblends = crender->fgblends;
+            crender->s.highcontrast = true;
+            crender->s.hcfgblends = crender->s.fgblends;
             crender->hcfg = cell_fchannel(targc);
           }
-          cell_blend_fchannel(targc, cell_fchannel(vis), &crender->fgblends);
+          unsigned fgblends = crender->s.fgblends;
+          cell_blend_fchannel(targc, cell_fchannel(vis), &fgblends);
+          crender->s.fgblends = fgblends;
           // crender->highcontrast can only be true if we just set it, since we're
           // about to set targc opaque based on crender->highcontrast (and this
           // entire stanza is conditional on targc not being CELL_ALPHA_OPAQUE).
-          if(crender->highcontrast){
+          if(crender->s.highcontrast){
             cell_set_fg_alpha(targc, CELL_ALPHA_OPAQUE);
           }
         }
       }
 
+      // Background color takes effect independently of whether we have a
+      // glyph. If we've already locked in the background, it has no effect.
+      // If it's transparent, it has no effect. Otherwise, update the
+      // background channel and balpha.
+      // Evaluate the background first, in case we have HIGHCONTRAST fg text.
+      if(cell_bg_alpha(targc) > CELL_ALPHA_OPAQUE){
+        const nccell* vis = &p->fb[nfbcellidx(p, y, x)];
+        // to be on the blitter stacking path, we need
+        //  1) crender->s.blittedquads to be non-zero
+        //  2) cell_blittedquadrants(vis) to be non-zero
+        //  3) somewhere crender is 0, blittedquads is 1
+        if(!crender->s.blittedquads || !((~crender->s.blittedquads) & cell_blittedquadrants(vis))){
+          if(cell_bg_default_p(vis)){
+            vis = &p->basecell;
+          }
+          if(cell_bg_palindex_p(vis)){
+            if(cell_bg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
+              cell_set_bg_palindex(targc, cell_bg_palindex(vis));
+            }
+          }else{
+            unsigned bgblends = crender->s.bgblends;
+            cell_blend_bchannel(targc, cell_bchannel(vis), &bgblends);
+            crender->s.bgblends = bgblends;
+          }
+        }else{ // use the local foreground; we're stacking blittings
+          if(cell_fg_default_p(vis)){
+            vis = &p->basecell;
+          }
+          if(cell_fg_palindex_p(vis)){
+            if(cell_bg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
+              cell_set_bg_palindex(targc, cell_fg_palindex(vis));
+            }
+          }else{
+            unsigned bgblends = crender->s.bgblends;
+            cell_blend_bchannel(targc, cell_fchannel(vis), &bgblends);
+            crender->s.bgblends = bgblends;
+          }
+          crender->s.blittedquads = 0;
+        }
+      }
+
       // if we never loaded any content into the cell (or obliterated it by
       // writing in a zero), use the plane's base cell.
       // if we have no character in this cell, we continue to look for a
@@ -322,6 +378,7 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
         // if the following is true, we're a real glyph, and not the right-hand
         // side of a wide glyph (nor the null codepoint).
         if( (targc->gcluster = vis->gcluster) ){ // index copy only
+          crender->s.blittedquads = cell_blittedquadrants(vis);
           // we can't plop down a wide glyph if the next cell is beyond the
           // screen, nor if we're bisected by a higher plane.
           if(cell_double_wide_p(vis)){
@@ -375,15 +432,16 @@ lock_in_highcontrast(nccell* targc, struct crender* crender){
   if(cell_bg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
     cell_set_bg_default(targc);
   }
-  if(crender->highcontrast){
+  if(crender->s.highcontrast){
     // highcontrast weighs the original at 1/4 and the contrast at 3/4
     if(!cell_fg_default_p(targc)){
-      crender->fgblends = 3;
+      unsigned fgblends = 3;
       uint32_t fchan = cell_fchannel(targc);
       uint32_t bchan = cell_bchannel(targc);
-      uint32_t hchan = channels_blend(highcontrast(bchan), fchan, &crender->fgblends);
+      uint32_t hchan = channels_blend(highcontrast(bchan), fchan, &fgblends);
       cell_set_fchannel(targc, hchan);
-      hchan = channels_blend(hchan, crender->hcfg, &crender->hcfgblends);
+      fgblends = crender->s.hcfgblends;
+      hchan = channels_blend(hchan, crender->hcfg, &fgblends);
       cell_set_fchannel(targc, hchan);
     }else{
       cell_set_fg_rgb(targc, highcontrast(cell_bchannel(targc)));
@@ -401,7 +459,7 @@ postpaint_cell(nccell* lastframe, int dimx, struct crender* crender,
   lock_in_highcontrast(targc, crender);
   nccell* prevcell = &lastframe[fbcellidx(y, dimx, *x)];
   if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc) > 0){
-    crender->damaged = true;
+    crender->s.damaged = true;
     assert(!cell_wide_right_p(targc));
     const int width = targc->width;
     for(int i = 1 ; i < width ; ++i){
@@ -415,7 +473,7 @@ postpaint_cell(nccell* lastframe, int dimx, struct crender* crender,
       targc->channels = crender[-i].c.channels;
       targc->stylemask = crender[-i].c.stylemask;
       if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc) > 0){
-        crender->damaged = true;
+        crender->s.damaged = true;
       }
     }
   }
@@ -855,7 +913,7 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
       const size_t damageidx = innery * nc->lfdimx + innerx;
       unsigned r, g, b, br, bg, bb, palfg, palbg;
       const nccell* srccell = &nc->lastframe[damageidx];
-      if(!rvec[damageidx].damaged){
+      if(!rvec[damageidx].s.damaged){
         // no need to emit a cell; what we rendered appears to already be
         // here. no updates are performed to elision state nor lastframe.
         ++nc->stats.cellelisions;
@@ -1066,7 +1124,7 @@ int notcurses_refresh(notcurses* nc, int* restrict dimy, int* restrict dimx){
   }
   memset(p.crender, 0, count * sizeof(*p.crender));
   for(int i = 0 ; i < count ; ++i){
-    p.crender[i].damaged = true;
+    p.crender[i].s.damaged = true;
   }
   int ret = notcurses_rasterize(nc, &p, nc->rstate.mstreamfp);
   free(p.crender);
@@ -1100,7 +1158,7 @@ int notcurses_render_to_file(notcurses* nc, FILE* fp){
   }
   memset(p.crender, 0, count * sizeof(*p.crender));
   for(int i = 0 ; i < count ; ++i){
-    p.crender[i].damaged = true;
+    p.crender[i].s.damaged = true;
   }
   int ret = raster_and_write(nc, &p, out);
   free(p.crender);
@@ -1133,40 +1191,42 @@ ncpile_render_internal(ncplane* n, struct crender* rvec, int leny, int lenx,
 }
 
 int ncpile_rasterize(ncplane* n){
-  struct timespec start, writedone;
+  struct timespec start, rasterdone, writedone;
   clock_gettime(CLOCK_MONOTONIC, &start);
   const ncpile* pile = ncplane_pile(n);
   struct notcurses* nc = ncplane_notcurses(n);
   const int miny = pile->dimy < nc->lfdimy ? pile->dimy : nc->lfdimy;
   const int minx = pile->dimx < nc->lfdimx ? pile->dimx : nc->lfdimx;
   postpaint(nc->lastframe, miny, minx, pile->crender, &nc->pool);
+  clock_gettime(CLOCK_MONOTONIC, &rasterdone);
   int bytes = notcurses_rasterize(nc, pile, nc->rstate.mstreamfp);
   // accepts -1 as an indication of failure
   update_render_bytes(&nc->stats, bytes);
   clock_gettime(CLOCK_MONOTONIC, &writedone);
-  update_write_stats(&writedone, &start, &nc->stats, bytes);
+  update_raster_stats(&rasterdone, &start, &nc->stats);
+  update_write_stats(&writedone, &rasterdone, &nc->stats, bytes);
   if(bytes < 0){
     return -1;
   }
   return 0;
 }
 
-// ensure the crender vector of 'n' is sufficiently large for
-// 'n'->dimy x 'n'->dimx, having previously been 'dimy'x'dimx', and initialize
-// the rvec afresh for a new render.
+// ensure the crender vector of 'n' is properly sized for 'n'->dimy x 'n'->dimx,
+// and initialize the rvec afresh for a new render.
 static int
-engorge_crender_vector(ncpile* n, int dimy, int dimx){
-  const int crenderlen = n->dimy * n->dimx; // desired size
-  if(crenderlen <= 0){
+engorge_crender_vector(ncpile* n){
+  if(n->dimy <= 0 || n->dimx <= 0){
     return -1;
   }
+  const size_t crenderlen = n->dimy * n->dimx; // desired size
 //fprintf(stderr, "crlen: %d y: %d x:%d\n", crenderlen, dimy, dimx);
-  if(crenderlen > dimy * dimx){
+  if(crenderlen != n->crenderlen){
     struct crender* tmp = realloc(n->crender, sizeof(*tmp) * crenderlen);
     if(tmp == NULL){
       return -1;
     }
     n->crender = tmp;
+    n->crenderlen = crenderlen;
   }
   init_rvec(n->crender, crenderlen);
   return 0;
@@ -1177,11 +1237,9 @@ int ncpile_render(ncplane* n){
   clock_gettime(CLOCK_MONOTONIC, &start);
   notcurses* nc = ncplane_notcurses(n);
   ncpile* pile = ncplane_pile(n);
-  const int olddimy = pile->dimy;
-  const int olddimx = pile->dimx;
   // update our notion of screen geometry, and render against that
   notcurses_resize_internal(n, NULL, NULL);
-  if(engorge_crender_vector(pile, olddimy, olddimx)){
+  if(engorge_crender_vector(pile)){
     return -1;
   }
   // FIXME notcurses_stdplane() doesn't belong here
