@@ -10,7 +10,7 @@ auto ncvisual_decode(ncvisual* nc) -> int {
   if(!visual_implementation){
     return -1;
   }
-  return visual_implementation->ncvisual_decode(nc);
+  return visual_implementation->visual_decode(nc);
 }
 
 auto ncvisual_blit(ncvisual* ncv, int rows, int cols, ncplane* n,
@@ -19,7 +19,7 @@ auto ncvisual_blit(ncvisual* ncv, int rows, int cols, ncplane* n,
                    bool blendcolors) -> int {
   int ret = -1;
   if(visual_implementation){
-    if(visual_implementation->ncvisual_blit(ncv, rows, cols, n, bset, placey, placex,
+    if(visual_implementation->visual_blit(ncv, rows, cols, n, bset, placey, placex,
                            begy, begx, leny, lenx, blendcolors) >= 0){
       ret = 0;
     }
@@ -37,13 +37,13 @@ auto ncvisual_blit(ncvisual* ncv, int rows, int cols, ncplane* n,
 // have been prepared already in 'ncv'.
 auto ncvisual_details_seed(struct ncvisual* ncv) -> void {
   if(visual_implementation){
-    visual_implementation->ncvisual_details_seed(ncv);
+    visual_implementation->visual_details_seed(ncv);
   }
 }
 
 auto ncvisual_init(int loglevel) -> int {
   if(visual_implementation){
-    return visual_implementation->ncvisual_init(loglevel);
+    return visual_implementation->visual_init(loglevel);
   }
   return 0;
 }
@@ -52,22 +52,19 @@ auto ncvisual_from_file(const char* filename) -> ncvisual* {
   if(!visual_implementation){
     return nullptr;
   }
-  return visual_implementation->ncvisual_from_file(filename);
+  return visual_implementation->visual_from_file(filename);
 }
 
 auto ncvisual_create(void) -> ncvisual* {
   if(visual_implementation){
-    return visual_implementation->ncvisual_create();
+    return visual_implementation->visual_create();
   }
   return new ncvisual{};
 }
 
 auto ncvisual_printbanner(const notcurses* nc) -> void {
   if(visual_implementation){
-    visual_implementation->ncvisual_printbanner(nc);
-  }else{
-    term_fg_palindex(nc, stderr, nc->tcache.colors <= 88 ? 1 % nc->tcache.colors : 0xcb);
-    fprintf(stderr, "\n Warning! Notcurses was built without multimedia support.\n");
+    visual_implementation->visual_printbanner(nc);
   }
 }
 
@@ -426,7 +423,7 @@ auto ncvisual_from_bgra(const void* bgra, int rows, int rowstride,
 auto ncvisual_render(notcurses* nc, ncvisual* ncv,
                      const struct ncvisual_options* vopts) -> ncplane* {
   if(vopts && vopts->flags > NCVISUAL_OPTION_BLEND){
-    fprintf(stderr, "Warning: unknown ncvisual options %016jx\n", (uintmax_t)vopts->flags);
+    logwarn(nc, "Warning: unknown ncvisual options %016jx\n", (uintmax_t)vopts->flags);
   }
   int lenx = vopts ? vopts->lenx : 0;
   int leny = vopts ? vopts->leny : 0;
@@ -546,7 +543,7 @@ auto ncvisual_from_plane(const ncplane* n, ncblitter_e blit, int begy, int begx,
 
 auto ncvisual_details_destroy(ncvisual_details* deets){
   if(visual_implementation){
-    visual_implementation->ncvisual_details_destroy(deets);
+    visual_implementation->visual_details_destroy(deets);
   }
 }
 
@@ -650,35 +647,31 @@ auto notcurses_canopen_videos(const notcurses* nc __attribute__ ((unused))) -> b
 }
 
 auto ncvisual_decode_loop(ncvisual* nc) -> int {
-  (void)nc;
-  return -1;
+  if(!visual_implementation){
+    return -1;
+  }
+  return visual_implementation->visual_decode_loop(nc);
 }
 
 auto ncvisual_stream(notcurses* nc, ncvisual* ncv, float timescale,
                      streamcb streamer, const ncvisual_options* vopts,
                      void* curry) -> int {
-  (void)nc;
-  (void)ncv;
-  (void)timescale;
-  (void)streamer;
-  (void)vopts;
-  (void)curry;
-  return -1;
+  if(!visual_implementation){
+    return -1;
+  }
+  return visual_implementation->visual_stream(nc, ncv, timescale, streamer, vopts, curry);
 }
 
 auto ncvisual_subtitle(const ncvisual* ncv) -> char* {
   if(!visual_implementation){
     return nullptr;
   }
-  return visual_implementation->ncvisual_subtitle(ncv);
+  return visual_implementation->visual_subtitle(ncv);
 }
 
 auto ncvisual_resize(ncvisual* nc, int rows, int cols) -> int {
-  // we'd need to verify that it's RGBA as well, except that if we've got no
-  // multimedia engine, we've only got memory-assembled ncvisuals, which are
-  // RGBA-native. so we ought be good, but this is undeniably sloppy...
-  if(nc->rows == rows && nc->cols == cols){
-    return 0;
+  if(!visual_implementation){
+    return -1;
   }
-  return -1;
+  return visual_implementation->visual_resize(nc, rows, cols);
 }
